@@ -130,7 +130,7 @@ void make_sgraph_from_graph_constr(sgraph* g, int** vertex_to_col, graph_constr*
     const int nv = graph->labels.size();
     int ne;
     if(directed_dimacs) {
-        //PRINT("[api] Parsing with directed DIMACS option...")
+        PRINT("[api] Parsing with directed DIMACS option...")
         assert(graph->edges.size() % 2 == 0);
         ne = graph->edges.size() / 2;
         g->initialize(nv, ne * 2);
@@ -227,15 +227,6 @@ void _graph_add_edge(graph_constr* graph, int v1, int v2) {
     assert(v1 != v2);
     assert(v1 < graph->labels.size());
     assert(v2 < graph->labels.size());
-
-    if(v1 > v2) {
-        int vs = v1;
-        v1 = v2;
-        v2 = vs;
-    }
-    //if(std::find(graph->edges.begin(), graph->edges.end(), std::pair<int, int>(v1, v2)) != graph->edges.end()) {
-    //    assert(false);
-    //}
     graph->edges.emplace_back(std::pair<int, int>(v1, v2));
 }
 
@@ -289,12 +280,6 @@ void make_sgraph_from_handle(sgraph* g, int** vertex_to_col, int graph_handle) {
             _graph_label(&subdivision_graph, edge_vertex_id, 1 + highest_label + graph->edge_labels[i]);
             ++edge_vertex_id;
         }
-        /*for(int i = 0; i < subdivision_graph.labels.size(); ++i) {
-            std::cout << "v" << i << " l: " << subdivision_graph.labels[i] << std::endl;
-        }
-        for(int i = 0; i < subdivision_graph.edges.size(); ++i) {
-            std::cout << "v" << subdivision_graph.edges[i].first << "--" << "v" << subdivision_graph.edges[i].second << std::endl;
-        }*/
         make_sgraph_from_graph_constr(g, vertex_to_col, &subdivision_graph, false);
     } else {
         make_sgraph_from_graph_constr(g, vertex_to_col, graph, graph->directed_dimacs);
